
.. currentmodule:: nilearn

.. include:: names.rst

0.1.2
=====

**Released March 2015**

Changelog
---------

- :bdg-dark:`Code` The ``0.1.2`` release is a bugfix release, specifically to fix the :class:`~maskers.NiftiMapsMasker`.
